PyZillow 0.6
============

PyZillow is a Python wrapper for `Zillow's API <http://www.zillow.com/howto/api/APIOverview.htm>`_. With PyZillow, you can use a physical address or a Zillow ID to access real estate data from the Zillow database.

Currently, PyZillow supports the **GetDeepSearchResults** and **GetUpdatedPropertyDetails** API endpoints.

Documentation
-------------

The PyZillow documentation is available here: http://pyzillow.readthedocs.org/en/latest/

Contributors
------------

* Alvaro Feito <alvaro@renooble.com>
* Bryce Boe <bbzbryce@gmail.com>
* Hannes Hapke <hannes@renooble.com>
* Miguel Paolino <miguel@renooble.com>
* Timo Cornelius Metzger <pyzillow@tcmetzger.net>

PyZillow was originally developed by Hannes Hapke and Miguel Paolino for `renooble.com <http://www.renooble.com>`_.
